@@ -1,3 +1,16 @@
+/*
+ * gpe-conf
+ *
+ * Copyright (C) 2002  Pierre TARDY <tardyp@free.fr>
+ *               2003,2004  Florian Boor <florian.boor@kernelconcepts.de>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version
+ * 2 of the License, or (at your option) any later version.
+ *
+ * User manager module.
+ */
 
 #include <gtk/gtk.h>
 #include <stdlib.h>
@@ -10,7 +23,6 @@
 #include <gpe/errorbox.h>
 #include <gpe/question.h>
 #include "../applets.h"
-#define _XOPEN_SOURCE_
 #include <unistd.h>
 #include <crypt.h>
 #include <time.h>
